@@ -1,11 +1,7 @@
 # display_parser -----
 
 
-#' @importFrom stringr str_extract_all str_split str_replace_all
 #' @importFrom R6 R6Class
-#' @importFrom purrr pmap_df map2_df pmap_chr
-#' @importFrom tibble tibble add_column as_tibble
-#' @importFrom lazyeval f_rhs f_lhs
 display_parser <- R6Class(
   "display_parser",
   public = list(
@@ -13,28 +9,55 @@ display_parser <- R6Class(
     initialize = function( x, formatters, fprops ) {
 
       private$str <- x
-      formatters <- map_df(formatters, function(x) {
-        tibble(varname = as.character(lazyeval::f_lhs(x) ),
-               expr = list(lazyeval::f_rhs(x) ) )
-      })
-      if( nrow(formatters) < 1 )
-        formatters <- tibble(varname = character(0 ) )
-      formatters$varname[is.na(formatters$varname)] <- "NA"
 
+      formatters_expr <- lapply(formatters, function(x) {
+        try(labels(terms(x)), silent = TRUE)
+      })
+
+      if( any( invalid_expr <- sapply(formatters_expr, inherits, "try-error") ) ){
+        invalid_expr <- paste0( "[", sapply( formatters[invalid_expr], format ), "]", collapse = ", " )
+        stop("invalid formatters elements (right-hand side): ", invalid_expr, call. = FALSE)
+      }
+
+
+      formatters_varname <- sapply(formatters, function(x) {
+        try(all.vars(x)[1], silent = TRUE)
+      })
+
+
+      if( any( invalid_varname <- sapply(formatters_varname, inherits, "try-error") ) ){
+        invalid_expr <- paste0( "[", sapply( formatters[invalid_varname], format ), "]", collapse = ", " )
+        stop("invalid formatters elements (left-hand side): ", invalid_expr, call. = FALSE)
+      }
+
+      formatters <- list(varname = formatters_varname, expr = formatters_expr)
+      # if( length(formatters_varname) > 1 ) browser()
       private$formatters <- formatters
 
-      pattern_ <- "\\{\\{[\\w\\.\\_]+\\}\\}"
-      r_expr <- str_extract_all(x, pattern = pattern_)[[1]]
-      r_char <- str_split(x, pattern_)[[1]]
+      pattern_ <- "\\{\\{[\\w\\.\\_ ]+\\}\\}"
+      matches_pos <- gregexpr(pattern = pattern_, text = x, perl = TRUE)[[1]]
 
-      str <- matrix( c(r_expr, r_char[-1]), byrow = TRUE, nrow = 2)
-      is_expr <- matrix( c(rep(TRUE, length(r_expr)), rep(FALSE, length(r_expr))), byrow = TRUE, nrow = 2)
+      if( length(matches_pos) == 1 && matches_pos == -1 ){
+        r_expr <- character(0)
+      }else {
+        r_expr <- mapply(function(x, pos, end) substr(x, pos, end ),
+               rep(x, length(matches_pos)),
+               matches_pos,
+               matches_pos + attr(matches_pos, "match.length") - 1, SIMPLIFY = FALSE )
+        r_expr <- unlist( setNames(r_expr, NULL) )
+      }
+      r_char <- strsplit( gsub(pattern_, replacement = "@@@", x, perl = TRUE), "@@@")[[1]]
 
-      str <- c( r_char[1], as.vector(str) )
-      is_expr <- c( FALSE, as.vector(is_expr) )
+      mat_nrow <- (length(r_char)>0)+(length(r_expr)>0)
+      str <- matrix( c(r_char, r_expr), byrow = FALSE, nrow = mat_nrow)
+      is_expr <- matrix( c(rep(FALSE, length(r_char)),
+                           rep(TRUE, length(r_expr)) ), byrow = FALSE, nrow = mat_nrow)
+
+      str <- as.vector(t(str))
+      is_expr <- as.vector(t(is_expr))
       pos <- seq_along(str)
 
-      data <- tibble(str = str, is_expr = is_expr, pos = pos)
+      data <- data.frame(str = str, is_expr = is_expr, pos = pos, stringsAsFactors = FALSE)
       data$rexpr <- gsub("(^\\{\\{|\\}\\})", "", data$str)
       data$rexpr[!is_expr] <- NA
 
@@ -42,15 +65,14 @@ display_parser <- R6Class(
         stop( shQuote(private$str), ": missing definition for display() 'formatters' arg ", call. = FALSE)
       }
 
+      data$pr_id <- rep(NA_character_, length(str))
+      fprops_id <- sapply(fprops, fp_sign)
+      if( length(fprops_id) ){
+        data$pr_id[match( names(fprops), data$rexpr )] <- fprops_id
+        fprops <- setNames(fprops, fprops_id)
+      }
       private$data <- data
-
-      lazy_f_id <- map_chr(fprops, fp_sign)
-      private$extra_fp <- tibble( pr_id = map_chr(fprops, fp_sign) )
-      if( length(fprops) ){
-        private$extra_fp$varname <- names(fprops)
-        names(fprops) <- lazy_f_id
-      } else private$extra_fp$varname <- character(0)
-      private$fprops <- fprops
+      private$fprops <- setNames(fprops, fprops_id)
     },
 
 
@@ -59,28 +81,47 @@ display_parser <- R6Class(
     },
 
     tidy_data = function(data){
-      dat <- merge(private$data, private$formatters, by.x = "rexpr", by.y = "varname", all.x = TRUE, all.y= FALSE, sort = FALSE)
-      dat <- merge(dat, private$extra_fp, by.x = "rexpr", by.y = "varname", all.x = TRUE, all.y= FALSE, sort = FALSE)
-      dat <- pmap_df( dat, function(str, is_expr, pos, rexpr, expr, pr_id, data){
-        if( is_expr ){
-          eval_out <- eval(expr, envir = data )
-          if( is.character(eval_out) )
-            tibble( str = eval_out, type_out = "text",
-                    id = seq_len(nrow(data)),
-                    pos = pos, pr_id = pr_id)
-          else if( inherits(eval_out, "image_entry") ){
-            add_column(eval_out, type_out = "image",
-                       id = seq_len(nrow(data)),
-                       pos = pos, pr_id = pr_id)
-          } else stop("could not get string from ", rexpr, "in ", private$str, ".", call. = FALSE)
-        } else{
-          tibble( str = rep(str, nrow(data) ), type_out = "text",
-                  id = seq_len(nrow(data)),
-                  pos = pos, pr_id = pr_id )
-        }
 
-      }, data = data )
-      dat
+      dat <- private$data
+      dat$expr <- lapply(seq_along(dat$str), function(x) NULL )
+      dat$expr[match( private$formatters$varname, private$data$rexpr )] <- private$formatters$expr
+
+      dat_expr <- dat[dat$is_expr,]
+
+      eval_out <- lapply(dat_expr$expr,
+                         function(x, data){
+                           with( data, eval(parse(text = x) ) )
+                           },
+                         data = data)
+      out_type <- rep(NA_character_, length(eval_out))
+      out_type <- ifelse(sapply(eval_out, inherits, "character" ), "text", out_type )
+      out_type <- ifelse(sapply(eval_out, inherits, "image_entry" ), "image", out_type )
+
+      if(length(eval_out) < 1){
+        dat_expr <- list( data.frame( str = character(0), type_out = character(0),
+                    id = integer(0),
+                    pos = integer(0), pr_id = character(0), stringsAsFactors = FALSE) )
+      } else
+        dat_expr <- mapply(function(x, type_out, pos, pr_id, n){
+            if( is.character(x) ){
+              x <- data.frame(str = x, stringsAsFactors = FALSE)
+            }
+            cbind( x, data.frame( type_out = type_out,
+                               id = seq_len(n),
+                               pos = pos, pr_id = pr_id, stringsAsFactors = FALSE) )
+          }, x = eval_out, type_out = out_type, pos = dat_expr$pos, pr_id = dat_expr$pr_id, n = nrow(data),
+          SIMPLIFY = FALSE )
+
+      dat_str <- dat[!dat$is_expr,]
+      dat_str <- mapply(function(x, pos, pr_id, n){
+
+        data.frame( str = x, type_out = "text",
+                    id = seq_len(n),
+                    pos = pos, pr_id = pr_id, stringsAsFactors = FALSE)
+      }, x = dat_str$str, pos = dat_str$pos, pr_id = dat_str$pr_id, n = nrow(data),
+      SIMPLIFY = FALSE )
+
+      rbind.match.columns(append(dat_expr, dat_str))
     }
 
 
@@ -106,7 +147,7 @@ fp_structure <- R6Class(
       ncol_ <- length(col_keys)
       id <- rep( seq_len( nrow_ ), ncol_ )
       keys <- rep(col_keys, each = nrow_ )
-      map_data <- tibble(id = id, col_key = keys)
+      map_data <- data.frame(id = id, col_key = keys, stringsAsFactors = FALSE)
       fp_signature <- fp_sign(fp)
       private$add_fp(fp, fp_signature)
       map_data$pr_id <- fp_signature
@@ -128,12 +169,9 @@ fp_structure <- R6Class(
 
     get_map_format = function( type ){
       dat <- self$get_map()
-      refs <- map_df(self$get_fp(),
-                         function(x, type)
-                           tibble( format = format(x, type = type )),
-                         type = type, .id = "pr_id")
-      match_ <- match( dat$pr_id, refs$pr_id )
-      dat$format <- refs$format[match_]
+      format_ = as.character( sapply(self$get_fp(), format, type = type ) )
+      match_ <- match( dat$pr_id, names(self$get_fp()) )
+      dat$format <- format_[match_]
       dat <- dat[, c("id", "col_key", "format") ]
       dat
     },
@@ -166,13 +204,14 @@ fp_structure <- R6Class(
       map_data_new <- private$map_data
       map_data_new <- map_data_new[map_data_new$id %in% model_id, ]
 
-
       if( first ){
-        map_data_new <- map_df(seq_len(nrows), function(x, dat) {dat$id <- x; dat }, map_data_new )
+        map_data_new <- lapply(seq_len(nrows), function(x, dat) {dat$id <- x; dat }, map_data_new )
+        map_data_new <- do.call(rbind, map_data_new)
         map_data$id <- map_data$id + nrows
         map_data <- rbind(map_data_new, map_data)
       } else {
-        map_data_new <- map_df(seq_len(nrows) + model_id - 1, function(x, dat) {dat$id <- x; dat }, map_data_new )
+        map_data_new <- lapply(seq_len(nrows) + model_id - 1, function(x, dat) {dat$id <- x; dat }, map_data_new )
+        map_data_new <- do.call(rbind, map_data_new)
         map_data_new$id <- map_data_new$id + nrows
         map_data <- rbind(map_data, map_data_new)
       }
@@ -203,14 +242,13 @@ display_structure <- R6Class(
   inherit = fp_structure,
   public = list(
 
-    initialize = function( nrow_, col_keys ) {
+    initialize = function( nrow_, col_keys, lazy_f ) {
       ncol_ <- length(col_keys)
       id <- rep( seq_len( nrow_ ), ncol_ )
       keys <- rep(col_keys, each = nrow_ )
-      map_data <- tibble(id = id, col_key = keys)
+      map_data <- data.frame(id = id, col_key = keys, stringsAsFactors = FALSE)
 
-      lazy_f <- map(col_keys, lazy_format_simple )
-      lazy_f_id <- map_chr(lazy_f, fp_sign)
+      lazy_f_id <- sapply(lazy_f, fp_sign)
       lazy_f_init <- rep(lazy_f_id, each = nrow_ )
 
       for(i in seq_along(lazy_f_id)){
@@ -225,7 +263,7 @@ display_structure <- R6Class(
       all_fp <- self$get_fp()
       all_ <- private$map_data$pr_id
       all_ <- unique(all_)
-      all_ <- map(all_, function(x){
+      all_ <- lapply(all_, function(x){
         all_fp[[x]]$get_fp()
       })
       all_ <- all_[sapply(all_, length)>0]
@@ -285,3 +323,18 @@ display_structure <- R6Class(
   )
 
 )
+
+
+rbind.match.columns <- function(list_df) {
+  col <- unique(unlist(sapply(list_df, names)))
+
+  list_df <- lapply(list_df, function(x, col) {
+    x[, setdiff(col, names(x))] <- NA
+    x
+  }, col = col)
+  list_df <- do.call(rbind, list_df)
+  row.names(list_df) <- NULL
+  list_df
+}
+
+
