@@ -73,4 +73,35 @@ test_that("width usage", {
   expect_error(width(ft, j = 1:2, width = rep(.7, 3)))
 })
 
+test_that("complextable and regulartable have same dimensions", {
+
+  typology <- data.frame(
+    col_keys = c( "Sepal.Length", "Sepal.Width", "Petal.Length",
+                  "Petal.Width", "Species" ),
+    what = c("Sepal", "Sepal", "Petal", "Petal", "Species"),
+    measure = c("Length", "Width", "Length", "Width", "Species"),
+    stringsAsFactors = FALSE )
+
+
+  data <- split( iris, iris$Species )
+  data <- lapply(data, function(x) x[1:3,])
+  data <- do.call(rbind, data)
+  row.names(data) <- NULL
+
+  col_keys <- c("Species", "sep_1", "Sepal.Length", "Sepal.Width", "sep_2",  "Petal.Length", "Petal.Width" )
+  ft1 <- flextable(data, col_keys = col_keys )
+  ft1 <- set_header_df(ft1, mapping = typology, key = "col_keys" )
+  ft1 <- empty_blanks(ft1)
+  ft1 <- autofit(ft1)
+
+  ft2 <- regulartable(data, col_keys = col_keys )
+  ft2 <- set_header_df(ft2, mapping = typology, key = "col_keys" )
+  ft2 <- empty_blanks(ft2)
+  ft2 <- autofit(ft2)
+
+  testthat::expect_equal(dim(ft1), dim(ft2))
+})
+
+
+
 
